%fresnel_knife_edge
% Plots Fresnel 'knife edge' diffraction pattern as a function of
% perpendicular range r from centre of the slit
%
% Assume uniformly illuminated.
%
% LAST UPDATED by Andy French 2/11/15

function fresnel_knife_edge

%Set fontsize
fsize = 18;

%Max value of Cornu Spiral
wmax = 5;

%Set wavelength /nm
%http://science-edu.larc.nasa.gov/EDDOCS/Wavelengths_for_Colors.html
lamda = 400;  %Violet
lamda = 445;  %Indigo
lamda = 475;  %Blue
lamda = 510;  %Green
lamda = 570;  %Yellow
lamda = 590;  %Orange
lamda = 650;  %Red

%Convert wavelength to m
lamda = lamda*1e-9;

%Set distance above knife edge
z = linspace( - 50*lamda, 200*lamda, 1000 );

%Set range /m in terms of multiples of wavelength
r = [100,500,1000]*lamda;

%Wavenumber /m^-1
k = 2*pi/lamda;

%Speed of light /ms^-1
c = 2.998e8;

%Calculate frequency /Hz
f = c/lamda;

%Determine intensity pattern amplitude variation with range.
%Assume a intensity per unit length of unity.
for n=1:length(r)
    w= 0.5*z*sqrt( 2/(lamda*r(n)) );
    II = (lamda/(2*r(n)))*( abs( 0.5*(1+1i) + fresnelC(w,0)+ 1i*fresnelS(w)) ).^2;
    I(:,n)=II;
    legend_str{n} = ['r = ',num2str(r(n)/lamda),'\lambda'];
end

%Plot intensity pattern (i.e. wave power)
figure;
plot( repmat(z.'/lamda,[1,length(r)] ),dBm(I));
xlabel( 'z /\lambda', 'fontsize',fsize );
ylabel('Normalized wave power /dBm','fontsize',fsize )
title(['Fresnel knife edge diffraction pattern: \lambda = ',...
    num2str(lamda*1e9),'nm'],'fontsize',fsize);
legend( legend_str,'fontsize',fsize );
axis tight
grid on;
set(gca,'fontsize',fsize);
print( gcf,'fresnel knife edge.png','-dpng','-r300');

%%

function y = dBm(x)
y = NaN(size(x));
k = x>0;
y(k) = 10*log10(x);
ymax = max(y(k));
y = y - ymax;

%End of code
