%fresnel_single_slit
% Plots Fresnel finite width slit diffraction pattern as a function of
% perpendicular range r from centre of the slit
%
% Assume uniformly illuminated.
%
% LAST UPDATED by Andy French 1/11/15

function fresnel_single_slit

%Set fontsize
fsize = 18;

%Max value of Cornu Spiral
wmax = 5;

%Set wavelength /nm
%http://science-edu.larc.nasa.gov/EDDOCS/Wavelengths_for_Colors.html
lamda = 400;  %Violet
lamda = 445;  %Indigo
lamda = 475;  %Blue
lamda = 510;  %Green
lamda = 570;  %Yellow
lamda = 590;  %Orange
lamda = 650;  %Red

%Convert wavelength to m
lamda = lamda*1e-9;

%Slit spacing /m. Note for Fresnel diffraction effects to be significant,
%the wavelength must be much less than the split width
a = 1000*lamda;

%Wavenumber /m^-1
k = 2*pi/lamda;

%Speed of light /ms^-1
c = 2.998e8;

%Calculate frequency /Hz
f = c/lamda;

%Calculate far-field range limit /m
r_far_field = (a^2)/lamda;

%Set range /m in terms of multiples of aperture width
r = linspace( 10*a, 150*a, 1000 );

%Determine intensity pattern amplitude variation with range.
%Assume a intensity per unit length of unity. 
w = 0.5*a*sqrt( 2./(lamda*r) );
I = (lamda./(2*r)).*( abs(fresnelC(w,0)+ 1i*fresnelS(w)) ).^2;

%Plot intensity pattern (i.e. wave power)
figure;
plot( r, dB(I) - dB(I(1)) );
xlabel( 'r /m', 'fontsize',fsize );
ylabel('Normalized wave power /dB','fontsize',fsize )
title(['Fresnel diffraction pattern: \lambda = ',...
    num2str(lamda*1e9),'nm,  a = ',num2str(a/lamda),'\lambda'],'fontsize',fsize);
axis tight
grid on;
set(gca,'fontsize',fsize);
print( gcf,'fresnel.png','-dpng','-r300');

%%

function y = dB(x)
y = NaN(size(x));
k = x>0;
y(k) = 10*log10(x);

%End of code
